Discover Packages
github.com/MontanaLab/golang-container
pkg
builder
dto
package
Version:
v1.1.2
Opens a new window with list of versions in this module.
Published: Jul 4, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Config struct {
Imports []string `json:"imports"`
Defaults Defaults `json:"defaults"`
Packages []Package `json:"packages"`
}
type Defaults struct {
Pointer bool `json:"pointer"`
Public bool `json:"public"`
}
type Env struct {
Module string `json:"module"`
Package string `json:"package"`
}
type Package struct {
Name string `json:"name"`
Services []Service `json:"services"`
}
type Service struct {
Name string `json:"name"`
Factory []string `json:"factory"`
Arguments []string `json:"arguments"`
Pointer *bool `json:"pointer"`
Public *bool `json:"public"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.